==> google-ads-1.1.1.tar.gz: google-ads-1.1.1/google/ads/google_ads/v1/services/transports/mutate_job_service_grpc_transport.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import google.api_core.grpc_helpers
import google.api_core.operations_v1

from google.ads.google_ads.v1.proto.services import mutate_job_service_pb2_grpc


class MutateJobServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.ads.googleads.v1.services MutateJobService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """
    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ()

    def __init__(self,
                 channel=None,
                 credentials=None,
                 address='googleads.googleapis.com:443'):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                'The `channel` and `credentials` arguments are mutually '
                'exclusive.', )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            'mutate_job_service_stub':
            mutate_job_service_pb2_grpc.MutateJobServiceStub(channel),
        }

        # Because this API includes a method that returns a
        # long-running operation (proto: google.longrunning.Operation),
        # instantiate an LRO client.
        self._operations_client = google.api_core.operations_v1.OperationsClient(
            channel)

    @classmethod
    def create_channel(cls,
                       address='googleads.googleapis.com:443',
                       credentials=None):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address,
            credentials=credentials,
            scopes=cls._OAUTH_SCOPES,
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def create_mutate_job(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.create_mutate_job`.

        Creates a mutate job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].CreateMutateJob

    @property
    def get_mutate_job(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.get_mutate_job`.

        Returns the mutate job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].GetMutateJob

    @property
    def list_mutate_job_results(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.list_mutate_job_results`.

        Returns the results of the mutate job. The job must be done.
        Supports standard list paging.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].ListMutateJobResults

    @property
    def run_mutate_job(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.run_mutate_job`.

        Runs the mutate job.

        The Operation.metadata field type is MutateJobMetadata. When finished, the
        long running operation will not contain errors or a response. Instead, use
        ListMutateJobResults to get the results of the job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].RunMutateJob

    @property
    def add_mutate_job_operations(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.add_mutate_job_operations`.

        Add operations to the mutate job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].AddMutateJobOperations

==> google-ads-3.1.0.tar.gz: google-ads-3.1.0/google/ads/google_ads/v1/services/transports/mutate_job_service_grpc_transport.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import google.api_core.grpc_helpers
import google.api_core.operations_v1

from google.ads.google_ads.v1.proto.services import mutate_job_service_pb2_grpc


class MutateJobServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.ads.googleads.v1.services MutateJobService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """
    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ()

    def __init__(self,
                 channel=None,
                 credentials=None,
                 address='googleads.googleapis.com:443'):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                'The `channel` and `credentials` arguments are mutually '
                'exclusive.', )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            'mutate_job_service_stub': mutate_job_service_pb2_grpc.MutateJobServiceStub(channel),
        }

        # Because this API includes a method that returns a
        # long-running operation (proto: google.longrunning.Operation),
        # instantiate an LRO client.
        self._operations_client = google.api_core.operations_v1.OperationsClient(channel)

    @classmethod
    def create_channel(
                cls,
                address='googleads.googleapis.com:443',
                credentials=None,
                **kwargs):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address,
            credentials=credentials,
            scopes=cls._OAUTH_SCOPES,
            **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def create_mutate_job(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.create_mutate_job`.

        Creates a mutate job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].CreateMutateJob

    @property
    def get_mutate_job(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.get_mutate_job`.

        Returns the mutate job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].GetMutateJob

    @property
    def list_mutate_job_results(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.list_mutate_job_results`.

        Returns the results of the mutate job. The job must be done.
        Supports standard list paging.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].ListMutateJobResults

    @property
    def run_mutate_job(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.run_mutate_job`.

        Runs the mutate job.

        The Operation.metadata field type is MutateJobMetadata. When finished, the
        long running operation will not contain errors or a response. Instead, use
        ListMutateJobResults to get the results of the job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].RunMutateJob

    @property
    def add_mutate_job_operations(self):
        """Return the gRPC stub for :meth:`MutateJobServiceClient.add_mutate_job_operations`.

        Add operations to the mutate job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs['mutate_job_service_stub'].AddMutateJobOperations
